==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm2015/lib/BollingerBandWidthIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { BollingerBandWidthIndicatorStrategy } from "./BollingerBandWidthIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let BollingerBandWidthIndicator = /*@__PURE__*/ (() => {
    class BollingerBandWidthIndicator extends StrategyBasedIndicator {
        get_up() {
            return new BollingerBandWidthIndicatorStrategy();
        }
        get up() {
            return this.get_up();
        }
        get_u2() {
            return BollingerBandWidthIndicator.$;
        }
        get u2() {
            return this.get_u2();
        }
        get vb() {
            return typeGetValue(this.c(BollingerBandWidthIndicator.ve));
        }
        set vb(a) {
            this.h(BollingerBandWidthIndicator.ve, a);
        }
        uv() {
            return this.vb;
        }
        get va() {
            return this.c(BollingerBandWidthIndicator.vd);
        }
        set va(a) {
            this.h(BollingerBandWidthIndicator.vd, a);
        }
        ut() {
            return this.va;
        }
    }
    BollingerBandWidthIndicator.$t = markType(BollingerBandWidthIndicator, 'BollingerBandWidthIndicator', StrategyBasedIndicator.$);
    BollingerBandWidthIndicator.ve = StrategyBasedIndicator.u7(20, BollingerBandWidthIndicator.$);
    BollingerBandWidthIndicator.vd = StrategyBasedIndicator.u6(2, BollingerBandWidthIndicator.$);
    return BollingerBandWidthIndicator;
})();

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm2015/lib/BollingerBandWidthIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { BollingerBandWidthIndicatorStrategy } from "./BollingerBandWidthIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let BollingerBandWidthIndicator = /*@__PURE__*/ (() => {
    class BollingerBandWidthIndicator extends StrategyBasedIndicator {
        get_yy() {
            return new BollingerBandWidthIndicatorStrategy();
        }
        get yy() {
            return this.get_yy();
        }
        get_zb() {
            return BollingerBandWidthIndicator.$;
        }
        get zb() {
            return this.get_zb();
        }
        get zk() {
            return typeGetValue(this.c(BollingerBandWidthIndicator.zn));
        }
        set zk(a) {
            this.h(BollingerBandWidthIndicator.zn, a);
        }
        y4() {
            return this.zk;
        }
        get zj() {
            return this.c(BollingerBandWidthIndicator.zm);
        }
        set zj(a) {
            this.h(BollingerBandWidthIndicator.zm, a);
        }
        y2() {
            return this.zj;
        }
    }
    BollingerBandWidthIndicator.$t = markType(BollingerBandWidthIndicator, 'BollingerBandWidthIndicator', StrategyBasedIndicator.$);
    BollingerBandWidthIndicator.zn = StrategyBasedIndicator.zg(20, BollingerBandWidthIndicator.$);
    BollingerBandWidthIndicator.zm = StrategyBasedIndicator.zf(2, BollingerBandWidthIndicator.$);
    return BollingerBandWidthIndicator;
})();
